/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.tez.common;

import java.util.Stack;
import java.util.concurrent.Callable;

import org.apache.log4j.NDC;

public abstract class CallableWithNdc<T> implements Callable<T> {
  private final Stack ndcStack;

  public CallableWithNdc() {
    ndcStack = NDC.cloneStack();
  }

  @Override
  public final T call() throws Exception {
    NDC.inherit(ndcStack);
    try {
      return callInternal();
    } finally {
      NDC.clear();
    }
  }

  protected abstract T callInternal() throws Exception;
}
