/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.tez.dag.app.launcher;

import java.io.IOException;

import org.apache.tez.dag.app.ErrorPluginConfiguration;
import org.apache.tez.serviceplugins.api.ContainerLaunchRequest;
import org.apache.tez.serviceplugins.api.ContainerLauncher;
import org.apache.tez.serviceplugins.api.ContainerLauncherContext;
import org.apache.tez.serviceplugins.api.ContainerStopRequest;
import org.apache.tez.serviceplugins.api.ServicePluginErrorDefaults;

public class TezTestServiceContainerLauncherWithErrors extends ContainerLauncher {

  private final ErrorPluginConfiguration conf;

  public TezTestServiceContainerLauncherWithErrors(
      ContainerLauncherContext containerLauncherContext) throws IOException,
      ClassNotFoundException {
    super(containerLauncherContext);
    conf = ErrorPluginConfiguration.toErrorPluginConfiguration(containerLauncherContext.getInitialUserPayload());
  }

  @Override
  public void launchContainer(ContainerLaunchRequest launchRequest) {
    ErrorPluginConfiguration.processError(conf, getContext());
  }

  @Override
  public void stopContainer(ContainerStopRequest stopRequest) {
    ErrorPluginConfiguration.processError(conf, getContext());
  }
}